# Documentation string. I wonder what ever refers to it? 

__doc__ = """Speedtest product module.

This module provides the methods and classes that Zope needs for the product. 
__init__.py is responsible for registering these methods and classes.

See README.txt for more details."""

# Version string. Usually updated automatically by CVS. 

__version__ = '0.2' # I used to wonder whether Zope checked these. Nope. 

# Now, you can compress these imports down to three lines, but that makes it 
# harder to document it as you go. Here's the long-winded version: 

from Globals import HTMLFile      # fakes a method from a DTML file
from Globals import MessageDialog # provid
from Globals import Persistent    # makes an object stick in the ZODB

import OFS.SimpleItem
import Acquisition
import AccessControl.Role

"""Step #1: Provide "constructors" for Zope's management interface. 
__init__ is all very well and good for Python, but doesn't provide 
a nice HTML interface or accept arguments from an HTTP request, so 
you need to provide some functions to act as a middle-man between 
Zope and your class.

Use HTMLFile to produce a [pseudo-]function which hands back an 
appropriate DTML document based on a file sitting in your product 
directory. 
"""

viewspeed_html = HTMLFile('viewspeed', globals()) 

manage_addSpeedtestForm = HTMLFile('speedtestAdd', globals()) 


def manage_addSpeedtest(self, id,title='', body_html='' ,REQUEST=None):
    """Add a Speedtest to a folder."""
    self._setObject(id, Speedtest(id, title,body_html))
    if REQUEST is not None:
        return self.manage_main(self, REQUEST)
	

"""Step #2: Provide the class for your Speedtest object."""

class Speedtest(
    OFS.SimpleItem.Item,   # A simple Principia object. Not Folderish. 
    Persistent,            # Make us persistent. Yaah! 
    Acquisition.Implicit,  # Uh, whatever. 
    AccessControl.Role.RoleManager # Security manager. 
    ): 
    """Speedtest object. 
    
    This is an attempt at writing a product from scratch using mostly 
    Python instead of ZClasses. We'll see how it all goes.
    """
        
    meta_type = 'Speedtest' # what do people think they're adding? 

    manage_options = ( # what management options are there?
	{'label': 'Edit',       'action': 'manage_main'},
	{'label': 'View',       'action': ''}, # defaults to index_html
	{'label': 'Security',   'action': 'manage_access'},
        {'label': 'About ',   'action': 'manage_about'}
	) 

    __ac_permissions__=( # what permissions make sense for us? 
	('View management screens', ('manage_tabs','manage_main')),
	('Change permissions',      ('manage_access',)           ),
	('Change Speedtest'     ,     ('manage_edit',)             ),
	('View Speedtest',            ('',)                        ),
	)

    def __init__(self, id, title='', body_html=''): 
        """initialise a new instance of Speedtest"""
        self.id = id
	self.title = title
	self.body_html = body_html
        self.speedtestfile = HTMLFile('speedtestfile', globals()) 
	self.viewspeed = HTMLFile('viewspeed', globals()) 
	 
    index_html = HTMLFile('index', globals()) # View Interface
    manage_about = HTMLFile('SpeedtestAbout', globals())         
    header_speedtest = HTMLFile('SpeedtestHeader', globals())         
    manage_main = HTMLFile('speedtestEdit', globals()) # Management Interface
    
    def manage_edit(self, title, body_html,REQUEST=None): 
        """does this really need a doc string?"""
	self.title = title	
	self.body_html = body_html
	if REQUEST is not None:
	    return MessageDialog(
		title = 'Edited',
		message = "Properties for %s changed." % self.id,
		action = './manage_main',
		)
